import{R as t}from"./Title.7b6ce571.js";import{E as n}from"./outputWidgets.17e2270d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="5593075f-20fc-4d36-b147-3ff4861a84eb",e._sentryDebugIdIdentifier="sentry-dbid-5593075f-20fc-4d36-b147-3ff4861a84eb")}catch{}})();const s=n(t);export{s as A};
//# sourceMappingURL=index.cfd05648.js.map
