import{F as c,H as l}from"./outputWidgets.17e2270d.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="72d97dea-8c6a-4a91-badd-5d2c53642d9d",r._sentryDebugIdIdentifier="sentry-dbid-72d97dea-8c6a-4a91-badd-5d2c53642d9d")}catch{}})();const f=r=>{const e=c({loading:!0,result:null,error:null}),n=t=>(e.value={loading:!1,result:t,error:null},t),a=t=>{e.value={loading:!1,result:null,error:t}},d=()=>{e.value={loading:!0,result:e.value.result,error:null},r().then(n).catch(a)};d();const o=l(()=>e.value.loading),s=l(()=>e.value.result),u=l(()=>e.value.error);return{loading:o,result:s,error:u,refetch:d}};export{f as a};
//# sourceMappingURL=asyncComputed.c8589796.js.map
