import{v as o,a,b as i,c,g as d,h as p,_,i as u,T as f,j as l,P as b,C as h,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.17e2270d.js";import{u as k}from"./index.678809b3.js";import"./pubsub.52f6192d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="371dec6c-fb56-43ba-a26d-4d5f764b6c40",e._sentryDebugIdIdentifier="sentry-dbid-371dec6c-fb56-43ba-a26d-4d5f764b6c40")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.3c0fe5bb.js"),["assets/Player.3c0fe5bb.js","assets/outputWidgets.17e2270d.js","assets/outputWidgets.e8fba759.css","assets/index.4787064b.js","assets/executeJs.dcb0cac7.js","assets/runnerData.07784255.js","assets/url.6c73df07.js","assets/icons.ae606380.js","assets/index.678809b3.js","assets/pubsub.52f6192d.js","assets/CircularLoading.1c3b33da.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.03251a7c.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.6af066e9.js","assets/Steps.998aa76d.css","assets/executeJs.acda9a57.css","assets/uuid.79e36a56.js","assets/broker.f8850d2a.js","assets/WidgetsFrame.b5c97561.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.6359e175.js","assets/broker.49d66771.css","assets/DashPlayer.828aa52d.js","assets/geometryUtils.16dd0e1b.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.c8589796.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(b),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.5a46d8d5.js.map
