import{d as g,ey as v,ez as b,r as k,b as r,c as s,w as a,u as e,f as u,ev as n}from"./outputWidgets.17e2270d.js";import{S as h,L as w}from"./SmartConsole.11639759.js";import{a as x}from"./asyncComputed.c8589796.js";import{H as B}from"./hooks.793ec9e4.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.6e46a263.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.93b7a046.js";import{B as I}from"./BaseLayout.0fbdf4d1.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.ce0a1a17.js";import{c as D}from"./index.038579df.js";import{A as _,T as R}from"./TabPane.f1ed80bf.js";import"./forms.4a239233.js";import"./activeRecord.1230459a.js";import"./pubsub.52f6192d.js";import"./dashes.f7f3f911.js";import"./runnerData.07784255.js";import"./jobs.5a9560be.js";import"./workspaces.1c8fc227.js";import"./url.6c73df07.js";import"./icons.ae606380.js";import"./Title.7b6ce571.js";import"./index.cfd05648.js";import"./uuid.79e36a56.js";import"./ant-design.8d97eacb.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.d5b385ae.js";import"./RunButton.vue_vue_type_script_setup_true_lang.c40d6c69.js";import"./index.43e45aad.js";import"./index.bedec2c6.js";import"./CollapsePanel.0785fbcd.js";import"./index.34b7172c.js";import"./index.29151007.js";import"./index.4b3be88e.js";import"./Form.0e9953f6.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="e49c84a9-e1d7-4934-9da0-020b297cd129",i._sentryDebugIdIdentifier="sentry-dbid-e49c84a9-e1d7-4934-9da0-020b297cd129")}catch{}})();const le=g({__name:"HookEditor",setup(i){const m=v(),l=b(),c=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(l.params.hookPath)),d=w.create();return($,f)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(R),{"active-key":o.value,"onUpdate:activeKey":f[0]||(f[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:c,hook:e(t),"log-service":e(d)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(d),onRestart:(p=c.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=HookEditor.1b27bd78.js.map
