import{d as y,ey as B,ez as C,r as D,H as L,b as t,et as s,bf as f,eA as h,e as _,eB as b,ex as g,f as o,I as v,ev as l,c as w,w as n,u,v as k,eC as $,eD as T,a as A,c0 as N,aI as O}from"./outputWidgets.17e2270d.js";import{f as V,h as j,j as E,d as H,c as R,m as z,w as F}from"./icons.ae606380.js";import{T as W}from"./Tooltip.dda20d9d.js";import{_ as J}from"./logo.084e5d7c.js";import{L as P}from"./LoginBlock.4e1307a1.js";import{_ as U}from"./DocsButton.vue_vue_type_script_setup_true_lang.93b7a046.js";import{B as q}from"./BaseLayout.0fbdf4d1.js";import{c as G}from"./index.038579df.js";import"./workspaces.1c8fc227.js";import"./activeRecord.1230459a.js";import"./pubsub.52f6192d.js";import"./url.6c73df07.js";import"./popupNotifcation.386010ff.js";import"./asyncComputed.c8589796.js";import"./index.23cb8791.js";import"./Title.7b6ce571.js";import"./index.ccccfee8.js";import"./Form.0e9953f6.js";import"./index.34b7172c.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="a877e0fc-c8d5-44b6-9589-c7c71f5117be",a._sentryDebugIdIdentifier="sentry-dbid-a877e0fc-c8d5-44b6-9589-c7c71f5117be")}catch{}})();const K={class:"sidebar"},M={class:"section-name"},Q=["onClick"],X={class:"item-name"},Y={key:0,class:"tag soon"},Z={key:1,class:"tag beta"},ee={key:2,class:"tag cloud"},ae=y({__name:"Sidebar",setup(a){var m;const r=B(),p=C(),c=D((m=p.name)!=null?m:"forms"),I=L(()=>[{name:"Runtime",items:[{name:"Forms",icon:V,path:"forms"},{name:"Hooks",icon:j,path:"hooks"},{name:"Jobs",icon:E,path:"jobs",cloud:!0},{name:"Dashes",icon:H,path:"dashes",beta:!0}]},{name:"Settings",items:[{name:"Style",icon:R,path:"style"},{name:"Sidebar",icon:z,path:"sidebar"}]}]),S=i=>{i.unavailable||(r.push(i.path),c.value=i.path)};return(i,le)=>(t(),s("div",K,[(t(!0),s(f,null,h(I.value,d=>(t(),s("div",{key:d.name,class:"section"},[_("span",M,b(d.name),1),(t(!0),s(f,null,h(d.items,e=>(t(),s("div",{key:e.name,role:"button",class:g(["item",{active:c.value===e.path,disabled:e.unavailable||d.cloud}]),tabindex:"0",onClick:_e=>S(e)},[o(v,{class:g(["icon",{disabled:e.unavailable,active:c.value===e.path}]),path:e.icon,width:"20",height:"20"},null,8,["class","path"]),_("span",X,b(e.name),1),e.unavailable?(t(),s("span",Y,"SOON")):l("",!0),e.beta?(t(),s("span",Z,"BETA")):l("",!0),e.cloud?(t(),s("span",ee,"CLOUD")):l("",!0),e.warning?(t(),w(W,{key:3,class:"warning",text:e.warning,fixed:!0,top:18,left:18},{default:n(()=>[o(v,{path:u(F),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):l("",!0)],10,Q))),128))]))),128))]))}});const te=k(ae,[["__scopeId","data-v-4c1da6de"]]);const se={},x=a=>($("data-v-81cd596e"),a=a(),T(),a),oe={class:"logo"},ne=x(()=>_("img",{src:J,alt:"Abstra cloud logo"},null,-1)),re=x(()=>_("span",null," Abstra ",-1)),ce=[ne,re];function ie(a,r){return t(),s("div",oe,ce)}const de=k(se,[["render",ie],["__scopeId","data-v-81cd596e"]]),Te=y({__name:"Workspace",setup(a){return(r,p)=>{const c=A("router-view");return t(),w(q,null,{navbar:n(()=>[o(u(G),{style:{padding:"5px 10px"}},{title:n(()=>[o(de)]),extra:n(()=>[o(u(N),{type:"primary",href:"/_editor/workflow"},{default:n(()=>[O("Workflow editor")]),_:1}),o(U),o(P)]),_:1})]),sidebar:n(()=>[o(te,{class:"sidebar"})]),content:n(()=>[o(c)]),_:1})}}});export{Te as default};
//# sourceMappingURL=Workspace.d9f8b6a4.js.map
