import"./outputWidgets.17e2270d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7ee9c73f-e3e6-4ab2-bf58-079ff811a60a",e._sentryDebugIdIdentifier="sentry-dbid-7ee9c73f-e3e6-4ab2-bf58-079ff811a60a")}catch{}})();const f=e=>{try{return new URL(e),!0}catch{return!1}};export{f as i};
//# sourceMappingURL=url.6c73df07.js.map
