import"./outputWidgets.17e2270d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="e9e27c71-c9bb-4518-908c-4143d4f53014",e._sentryDebugIdIdentifier="sentry-dbid-e9e27c71-c9bb-4518-908c-4143d4f53014")}catch{}})();function s(e){return e.charAt(0).toUpperCase()+e.slice(1)}function d(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{s as c,d as n};
//# sourceMappingURL=string.61f49d8a.js.map
