import{cC as n}from"./outputWidgets.17e2270d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="8a97f0b0-eaf5-417c-aa06-1383fa1e67de",e._sentryDebugIdIdentifier="sentry-dbid-8a97f0b0-eaf5-417c-aa06-1383fa1e67de")}catch{}})();const o=(e,r)=>{n.error({message:e,description:r})};export{o as p};
//# sourceMappingURL=popupNotifcation.386010ff.js.map
