import{d as g,ey as v,ez as k,r as b,b as r,c as a,w as s,u as e,f as u,ev as n}from"./outputWidgets.17e2270d.js";import{S as j,L as w}from"./SmartConsole.11639759.js";import{a as x}from"./asyncComputed.c8589796.js";import{J as I}from"./jobs.5a9560be.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.6e46a263.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.93b7a046.js";import{B as S}from"./BaseLayout.0fbdf4d1.js";import{_ as T,a as D}from"./JobSettings.vue_vue_type_script_setup_true_lang.a9ab755d.js";import{c as R}from"./index.038579df.js";import{A as _,T as $}from"./TabPane.f1ed80bf.js";import"./forms.4a239233.js";import"./activeRecord.1230459a.js";import"./pubsub.52f6192d.js";import"./dashes.f7f3f911.js";import"./runnerData.07784255.js";import"./hooks.793ec9e4.js";import"./workspaces.1c8fc227.js";import"./url.6c73df07.js";import"./icons.ae606380.js";import"./Title.7b6ce571.js";import"./index.cfd05648.js";import"./uuid.79e36a56.js";import"./ant-design.8d97eacb.js";import"./RunButton.vue_vue_type_script_setup_true_lang.c40d6c69.js";import"./index.ab9babdf.js";import"./index.4b3be88e.js";import"./dayjs.480d260c.js";import"./Form.0e9953f6.js";import"./index.34b7172c.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="c2a448a8-17c5-4257-a048-b17edbb47f2a",i._sentryDebugIdIdentifier="sentry-dbid-c2a448a8-17c5-4257-a048-b17edbb47f2a")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),l=k(),c=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(l.params.jobId)),f=w.create();return(A,d)=>(r(),a(S,null,{navbar:s(()=>[e(t)?(r(),a(e(R),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:s(()=>[u(e($),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:s(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[u(C),o.value==="settings"?(r(),a(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(T,{key:0,ref_key:"tester",ref:c,job:e(t),"log-service":e(f)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),a(D,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:s(()=>{var p;return[e(t)&&o.value==="test"?(r(),a(j,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=c.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.833535b9.js.map
