import{v as t,b as s,et as d}from"./outputWidgets.17e2270d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="2db06f9e-e1d6-4989-9e37-edce9397e8d3",e._sentryDebugIdIdentifier="sentry-dbid-2db06f9e-e1d6-4989-9e37-edce9397e8d3")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),d("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.5927f77b.js.map
