import{d as r,r as c,o as u,eS as f,b as y,c as p,w as d,f as b,aI as g,eB as m,eO as w,u as i,c0 as k,eW as _}from"./outputWidgets.17e2270d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1f2b66a5-a03d-4964-924b-c2e683894370",e._sentryDebugIdIdentifier="sentry-dbid-1f2b66a5-a03d-4964-924b-c2e683894370")}catch{}})();const B=r({__name:"ActionButton",props:{action:{},displayName:{},loading:{type:Boolean}},emits:["click"],setup(e,{emit:n}){const a=e,o=c(null);return u(()=>{o.value&&a.action.setElement(o.value),f.addAction(a.action)}),(s,t)=>(y(),p(i(_),null,{default:d(()=>[b(i(k),{ref_key:"element",ref:o,class:"next-button",loading:s.loading,onClick:t[0]||(t[0]=l=>n("click")),onKeydown:t[1]||(t[1]=w(l=>n("click"),["enter"]))},{default:d(()=>[g(m(s.displayName),1)]),_:1},8,["loading"])]),_:1}))}});export{B as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.6359e175.js.map
