import{v as a}from"./icons.ae606380.js";import{d as r,a as c,b as i,et as d,f as _,u as f,aI as l,v as u}from"./outputWidgets.17e2270d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c823badb-3595-4476-9110-c55302f84fe4",e._sentryDebugIdIdentifier="sentry-dbid-c823badb-3595-4476-9110-c55302f84fe4")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.5eee5ad3.js.map
