import{V as i}from"./outputWidgets.17e2270d.js";import{c as a,d}from"./index.ab9babdf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ebc11390-b392-444b-8cc3-8001f84b0b88",e._sentryDebugIdIdentifier="sentry-dbid-ebc11390-b392-444b-8cc3-8001f84b0b88")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:b,TimePicker:f,QuarterPicker:o,RangePicker:c}=a(d),y=i(n,{WeekPicker:r,MonthPicker:t,YearPicker:b,RangePicker:c,TimePicker:f,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.8b947026.js.map
